aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-ptpip.c
diff options
context:
space:
mode:
Diffstat (limited to 'epan/dissectors/packet-ptpip.c')
-rw-r--r--epan/dissectors/packet-ptpip.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/epan/dissectors/packet-ptpip.c b/epan/dissectors/packet-ptpip.c
index 6d8114a6e0..94c5086b39 100644
--- a/epan/dissectors/packet-ptpip.c
+++ b/epan/dissectors/packet-ptpip.c
@@ -1123,12 +1123,12 @@ void proto_reg_handoff_ptpIP( void ) {
dissector_handle_t ptpIP_handle;
/* Use new_create_dissector_handle() to indicate that dissect_ptpIP()
* returns the number of bytes it dissected (or 0 if it thinks the packet
* does not belong to PROTONAME).
*/
- ptpIP_handle = new_create_dissector_handle(dissect_ptpIP, proto_ptpIP);
+ ptpIP_handle = create_dissector_handle(dissect_ptpIP, proto_ptpIP);
dissector_add_uint("tcp.port", PTPIP_PORT, ptpIP_handle);
}
@@ -1123,12 +1123,12 @@ void proto_reg_handoff_ptpIP( void ) {
dissector_handle_t ptpIP_handle;
- /* Use new_create_dissector_handle() to indicate that dissect_ptpIP()
+ /* Use create_dissector_handle() to indicate that dissect_ptpIP()
* returns the number of bytes it dissected (or 0 if it thinks the packet
* does not belong to PROTONAME).